@@ -6,7 +6,7 @@ from typing import List, Optional, Sequence, Union
 from pydicom.datadict import tag_for_keyword
 from pydicom.dataset import Dataset, FileMetaDataset
 from pydicom.filewriter import write_file_meta_info
-from pydicom.uid import ExplicitVRBigEndian, ImplicitVRLittleEndian, UID
+from pydicom.uid import ImplicitVRLittleEndian, UID
 from pydicom.valuerep import DA, PersonName, TM
 
 from highdicom.coding_schemes import CodingSchemeIdentificationItem
@@ -18,6 +18,7 @@ from highdicom.valuerep import check_person_name
 from highdicom.version import __version__
 from highdicom._iods import IOD_MODULE_MAP, SOP_CLASS_UID_IOD_KEY_MAP
 from highdicom._modules import MODULE_ATTRIBUTE_MAP
+from highdicom._module_utils import is_attribute_in_iod
 
 
 logger = logging.getLogger(__name__)
@@ -116,20 +117,20 @@ class SOPClass(Dataset):
         super().__init__()
         if transfer_syntax_uid is None:
             transfer_syntax_uid = ImplicitVRLittleEndian
-        if transfer_syntax_uid == ExplicitVRBigEndian:
-            self.is_little_endian = False
-        else:
-            self.is_little_endian = True
-        if transfer_syntax_uid == ImplicitVRLittleEndian:
-            self.is_implicit_VR = True
-        else:
-            self.is_implicit_VR = False
+        transfer_syntax_uid = UID(transfer_syntax_uid)
+        if not transfer_syntax_uid.is_little_endian:
+            raise ValueError(
+                "Big Endian transfer syntaxes are retired and no longer "
+                "supported by highdicom."
+            )
+        self.is_little_endian = True  # backwards compatibility
+        self.is_implicit_VR = transfer_syntax_uid.is_implicit_VR
 
         # Include all File Meta Information required for writing SOP instance
         # to a file in PS3.10 format.
         self.preamble = b'\x00' * 128
         self.file_meta = FileMetaDataset()
-        self.file_meta.TransferSyntaxUID = UID(transfer_syntax_uid)
+        self.file_meta.TransferSyntaxUID = transfer_syntax_uid
         self.file_meta.MediaStorageSOPClassUID = UID(sop_class_uid)
         self.file_meta.MediaStorageSOPInstanceUID = UID(sop_instance_uid)
         self.file_meta.FileMetaInformationVersion = b'\x00\x01'
@@ -190,8 +191,12 @@ class SOPClass(Dataset):
                 '"instance_number" should be a positive integer.'
             )
         self.InstanceNumber = instance_number
-        self.ContentDate = DA(datetime.datetime.now().date())
-        self.ContentTime = TM(datetime.datetime.now().time())
+
+        # Content Date and Content Time are not present in all IODs
+        if is_attribute_in_iod('ContentDate', sop_class_uid):
+            self.ContentDate = DA(datetime.datetime.now().date())
+        if is_attribute_in_iod('ContentTime', sop_class_uid):
+            self.ContentTime = TM(datetime.datetime.now().time())
         if content_qualification is not None:
             content_qualification = ContentQualificationValues(
                 content_qualification
@@ -303,3 +308,30 @@ class SOPClass(Dataset):
 
         """
         self._copy_root_attributes_of_module(dataset, 'Image', 'Specimen')
+
+
+def _check_little_endian(dataset: Dataset) -> None:
+    """Assert that a dataset uses a little endian transfer syntax.
+
+    Parameters
+    ----------
+    dataset: Dataset
+        Dataset to check.
+
+    Raises
+    ------
+    ValueError:
+        If the dataset does not use a little endian transfer syntax.
+
+    """
+    if not hasattr(dataset, 'file_meta'):
+        logger.warning(
+            'Transfer syntax cannot be determined from the file metadata.'
+            'Little endian encoding of attributes has been assumed.'
+        )
+        return
+    if not dataset.file_meta.TransferSyntaxUID.is_little_endian:
+        raise ValueError(
+            'Parsing of datasets is only valid for datasets with little endian '
+            'transfer syntaxes.'
+        )
