@@ -2,6 +2,7 @@
 
 import logging
 from collections import defaultdict
+from datetime import datetime
 from typing import Any, Dict, List, Optional, Sequence
 
 from pydicom.datadict import tag_for_keyword
@@ -171,10 +172,9 @@ def _convert_legacy_to_enhanced(
         # Frame Content (M)
         frame_content_item = Dataset()
         if 'AcquisitionDate' in ds and 'AcquisitionTime' in ds:
-            frame_content_item.FrameAcquisitionDateTime = '{}{}'.format(
-                ds.AcquisitionDate,
-                ds.AcquisitionTime
-            )
+            frame_content_item.FrameAcquisitionDateTime = datetime.combine(
+                ds.AcquisitionDate, ds.AcquisitionTime
+            ).strftime('%Y%m%d%H%M%S')
         frame_content_item.FrameAcquisitionNumber = ds.InstanceNumber
         perframe_item.FrameContentSequence = [
             frame_content_item,
