@@ -173,30 +173,32 @@ class TestLegacyConvertedEnhancedImage(unittest.TestCase):
             with self.subTest(m=m):
                 LegacyConverterClass = getattr(
                     sop,
-                    "LegacyConvertedEnhanced{}Image".format(m)
+                    f'LegacyConvertedEnhanced{m}Image'
                 )
-                ref_dataset_seq = getattr(self, f"_ref_dataset_seq_{m}")
+                ref_dataset_seq = getattr(self, f'_ref_dataset_seq_{m}')
                 # first run with intact input
                 LegacyConverterClass(
                     legacy_datasets=ref_dataset_seq,
                     series_instance_uid=self._output_series_instance_uid,
                     series_number=self._output_instance_number,
                     sop_instance_uid=self._output_sop_instance_uid,
-                    instance_number=self._output_instance_number)
+                    instance_number=self._output_instance_number
+                )
                 # second run with defected input
-                tmp_transfer_syntax_uid = ref_dataset_seq[
-                    0].file_meta.TransferSyntaxUID
-                ref_dataset_seq[
-                    0].file_meta.TransferSyntaxUID = '1.2.3.4.5.6.7.8.9'
+                ref_item = ref_dataset_seq[0]
+                tmp_transfer_syntax_uid = str(
+                    ref_item.file_meta.TransferSyntaxUID
+                )
+                ref_item.file_meta.TransferSyntaxUID = '1.2.3.4.5.6.7.8.9'
                 with self.assertRaises(ValueError):
                     LegacyConverterClass(
                         legacy_datasets=ref_dataset_seq,
                         series_instance_uid=self._output_series_instance_uid,
                         series_number=self._output_instance_number,
                         sop_instance_uid=self._output_sop_instance_uid,
-                        instance_number=self._output_instance_number)
-                ref_dataset_seq[
-                    0].file_meta.TransferSyntaxUID = tmp_transfer_syntax_uid
+                        instance_number=self._output_instance_number
+                    )
+                ref_item.file_meta.TransferSyntaxUID = tmp_transfer_syntax_uid
 
     def generate_common_dicom_dataset_series(
         self,
